package jdk.internal.org.objectweb.asm.tree;

import java.util.ArrayList;
import java.util.List;
import jdk.internal.org.objectweb.asm.AnnotationVisitor;

public class AnnotationNode extends AnnotationVisitor
{
    public String desc;
    public List<Object> values;
    
    public AnnotationNode(String s) {
        this(327680, s);
        if (this.getClass() != AnnotationNode.class) {
            throw new IllegalStateException();
        }
        return;
    }
    
    public AnnotationNode(int api, String desc) {
        super(api);
        this.desc = desc;
    }
    
    AnnotationNode(List<Object> values) {
        super(327680);
        this.values = values;
    }
    
    @Override
    public void visit(String s, Object o) {
        if (this.values == null) {
            this.values = new ArrayList((this.desc != null) ? 2 : 1);
        }
        if (this.desc != null) {
            this.values.add(s);
        }
        this.values.add(o);
    }
    
    @Override
    public void visitEnum(String s, String s2, String s3) {
        if (this.values == null) {
            this.values = new ArrayList((this.desc != null) ? 2 : 1);
        }
        if (this.desc != null) {
            this.values.add(s);
        }
        this.values.add(new String[] { s2, s3 });
    }
    
    @Override
    public AnnotationVisitor visitAnnotation(String s, String s2) {
        if (this.values == null) {
            this.values = new ArrayList((this.desc != null) ? 2 : 1);
        }
        if (this.desc != null) {
            this.values.add(s);
        }
        AnnotationNode annotationNode = new AnnotationNode(s2);
        this.values.add(annotationNode);
        return annotationNode;
    }
    
    @Override
    public AnnotationVisitor visitArray(String s) {
        if (this.values == null) {
            this.values = new ArrayList((this.desc != null) ? 2 : 1);
        }
        if (this.desc != null) {
            this.values.add(s);
        }
        ArrayList<Object> list = new ArrayList();
        this.values.add(list);
        return new AnnotationNode(list);
    }
    
    @Override
    public void visitEnd() {
    }
    
    public void check(int n) {
    }
    
    public void accept(AnnotationVisitor annotationVisitor) {
        if (annotationVisitor != null) {
            if (this.values != null) {
                for (int i = 0; i < this.values.size(); i += 2) {
                    accept(annotationVisitor, (String)this.values.get(i), this.values.get(i + 1));
                }
            }
            annotationVisitor.visitEnd();
        }
    }
    
    static void accept(AnnotationVisitor annotationVisitor, String s, Object value) {
        if (annotationVisitor != null) {
            if ((value instanceof String[])) {
                String[] array = (String[])(String[])value;
                annotationVisitor.visitEnum(s, array[0], array[1]);
            }
            else if ((value instanceof AnnotationNode)) {
                AnnotationNode annotationNode = (AnnotationNode)value;
                annotationNode.accept(annotationVisitor.visitAnnotation(s, annotationNode.desc));
            }
            else if ((value instanceof List)) {
                AnnotationVisitor visitArray = annotationVisitor.visitArray(s);
                if (visitArray != null) {
                    List<Object> list = (List)value;
                    for (int i = 0; i < list.size(); ++i) {
                        accept(visitArray, null, list.get(i));
                    }
                    visitArray.visitEnd();
                }
            }
            else {
                annotationVisitor.visit(s, value);
            }
        }
    }
}
